@@ -32,6 +32,7 @@ class DataExchanger():
     def __init__(self, context: Optional[Context], loop_communicator: LoopCommunicator):
         self.context = context
         self.loop_communicator = loop_communicator
+        self.progress = 0.0
 
     def set_context(self, context: Context):
         self.context = context
@@ -59,7 +60,6 @@ class DataExchanger():
             logging.warning('context was not set yet')
             return
 
-        await self.delete_corrupt_images(image_folder)
         new_image_ids = await asyncio.get_event_loop().run_in_executor(None, DataExchanger.filter_existing_images, image_ids, image_folder)
         paths, ids = create_resource_paths(self.context.organization, self.context.project, new_image_ids)
         await self._download_images(paths, ids, image_folder)
@@ -96,10 +96,16 @@ class DataExchanger():
 
     async def _download_images_data(self, organization: str, project: str, image_ids: List[str], chunk_size: int = 100) -> List[Dict]:
         logging.info('fetching annotations and other image data')
+        num_image_ids = len(image_ids)
         self.jepeg_check_info()
         images_data = []
+        if num_image_ids == 0:
+            logging.info('got empty list. No images were downloaded')
+            return images_data
         starttime = time.time()
-        for i in tqdm(range(0, len(image_ids), chunk_size), position=0, leave=True):
+        progress_factor = 0.5 / num_image_ids  # 50% of progress is for downloading data
+        for i in tqdm(range(0, num_image_ids, chunk_size), position=0, leave=True):
+            self.progress = i * progress_factor
             chunk_ids = image_ids[i:i+chunk_size]
             response = await self.loop_communicator.get(f'/{organization}/projects/{project}/images?ids={",".join(chunk_ids)}')
             if response.status_code != 200:
@@ -116,13 +122,17 @@ class DataExchanger():
         return images_data
 
     async def _download_images(self, paths: List[str], image_ids: List[str], image_folder: str, chunk_size: int = 10) -> None:
-        if len(image_ids) == 0:
+        num_image_ids = len(image_ids)
+        if num_image_ids == 0:
             logging.debug('got empty list. No images were downloaded')
             return
         logging.info('fetching image files')
         starttime = time.time()
         os.makedirs(image_folder, exist_ok=True)
-        for i in tqdm(range(0, len(image_ids), chunk_size), position=0, leave=True):
+
+        progress_factor = 0.5 / num_image_ids  # second 50% of progress is for downloading images
+        for i in tqdm(range(0, num_image_ids, chunk_size), position=0, leave=True):
+            self.progress = 0.5 + i * progress_factor
             chunk_paths = paths[i:i+chunk_size]
             chunk_ids = image_ids[i:i+chunk_size]
             tasks = []
